==> zzyj-outputvalcount-api-3.0.0-20230923.013901-258-sources.jar: com/ejianc/business/outputvalcount/utils/SMS.java <==
package com.ejianc.business.outputvalcount.utils;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLEncoder;

public class SMS {

    private Logger logger = LoggerFactory.getLogger(this.getClass());
    /**
     * 发送短信
     * @param accName 用户名
     * @param accPwd 密码
     * @param mobies 手机号多个手机号之间英文半角逗号隔开
     * @param content 内容后加签名
     * @param schTime 定时时间格式如：2010-01-01 08:00:00 为空则及时发送
     * @return 服务端返回的结果 ok:业务id 或者 错误代码
     */
    private  static String sendSms(String accName,String accPwd,String mobies,String content,String schTime){
        StringBuffer sb = new StringBuffer("http://sdk.lx198.com/sdk/send?");
        try {
            sb.append("&accName="+accName);
            sb.append("&accPwd="+MD5.getMd5String(accPwd));
            sb.append("&aimcodes="+mobies);
            sb.append("&schTime="+ URLEncoder.encode(schTime,"UTF-8")); //空格标点符号做encode转换
            sb.append("&content="+URLEncoder.encode(content,"UTF-8")); //中文做encode转换
            URL url = new URL(sb.toString());
            System.out.println("发送短信url："+url);
            HttpURLConnection connection = (HttpURLConnection) url.openConnection();
            connection.setRequestMethod("POST");
            BufferedReader in = new BufferedReader(new InputStreamReader(url.openStream()));
            return in.readLine();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }
    public static void setSendSms(String mobies,String content){
        String schTime="";
        String s = sendSms("18689202959", "123456", mobies, content, schTime);
        System.out.println(s);
    }
}

==> zzyj-outputvalcount-api-3.0.0-20250115.075045-354-sources.jar: com/ejianc/business/outputvalcount/utils/SMS.java <==
package com.ejianc.business.outputvalcount.utils;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLEncoder;

public class SMS {

    private Logger logger = LoggerFactory.getLogger(this.getClass());
    /**
     * 发送短信
     * @param accName 用户名
     * @param accPwd 密码
     * @param mobies 手机号多个手机号之间英文半角逗号隔开
     * @param content 内容后加签名
     * @param schTime 定时时间格式如：2010-01-01 08:00:00 为空则及时发送
     * @return 服务端返回的结果 ok:业务id 或者 错误代码
     */
    private  static String sendSms(String accName,String accPwd,String mobies,String content,String schTime){
        StringBuffer sb = new StringBuffer("http://sdk.lx198.com/sdk/send?");
        try {
            sb.append("&AppID="+accName);
            sb.append("&AppSecret="+accPwd);
            sb.append("&aimcodes="+mobies);
            sb.append("&schTime="+ URLEncoder.encode(schTime,"UTF-8")); //空格标点符号做encode转换
            sb.append("&content="+URLEncoder.encode(content,"UTF-8")); //中文做encode转换
            URL url = new URL(sb.toString());
            System.out.println("发送短信url："+url);
            HttpURLConnection connection = (HttpURLConnection) url.openConnection();
            connection.setRequestMethod("POST");
            BufferedReader in = new BufferedReader(new InputStreamReader(url.openStream()));
            return in.readLine();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }
    public static void setSendSms(String mobies,String content){
        String schTime="";
        String s = sendSms("zQVVYM8M", "547998c157ed89b13e9ad9c52d3c580b8b5cc26d", mobies, content, schTime);
        System.out.println(s);
    }
}
